# GENETIC RECONSTRUCTION OF A BULLFROG INVASION TO ELUCIDATE VECTORS OF INTRODUCTION AND SECONDARY SPREAD
# Pauline L. Kamath*, U.S. Geological Survey, Northern Rocky Mountain Science Center, Bozeman, MT  59715
# Adam Sepulveda, U.S. Geological Survey, Northern Rocky Mountain Science Center, Bozeman, MT  59715
# Megan Layhee, U.S. Geological Survey, Northern Rocky Mountain Science Center, Bozeman, MT  59715
# * email: pkamath@usgs.gov


# SUPPORTING INFORMATION
#R code for models examining Isolation by Distance of invasive bullfrogs in the Yellowstone River

###########################################################
# Getting data, set up
###########################################################

# Clear the global environment
rm(list = ls())

# Load required packages
library(ecodist)
library(MASS)
require(mgcv)

# Reference for data: 
# Kamath, P.L., Sepulveda, A. & Layhee, M. (2016) Data from "Genetic reconstruction
# of a bullfrog invasion to elucidate vectors of introduction and secondary spread",
# Ecology and Evolution, http://dx.doi.org/10.5061/dryad.g81c8


# Save data and set the working directory to your folder
setwd("C://your folder")

#Yellowstone River haplotype (H1, H2) distribution data
HapDist <-read.csv("Yellowstone_HapDistribution.csv", header = TRUE, sep = ",")
names (HapDist)
DIST <- as.numeric(HapDist$Distance)
H1<- as.numeric(HapDist$H1prop)
H2<- as.numeric(HapDist$H2prop)
N<- as.numeric(HapDist$N)

#FST (GD) and geographic distance (GGD) data from pairwise site comparisons
IBD <- read.csv("Yellowstone_FSTbyDIST.csv", header = TRUE, sep = ",")
names(IBD)
GGD <- as.numeric(IBD$GGD)
GD <- as.numeric(IBD$GD)

#########################################################
# Generalized Linear Model(haplotype proportion as a function of river distance)
#########################################################

#Models

M1<-glm(H1 ~ DIST, family=binomial, data=HapDist, weights= N)
M2<-glm(H2 ~ DIST, family=binomial, data=HapDist, weights= N)
summary(M1)
summary(M2)

#GLM PLots: Figure 4 inset
op <- par(mfrow = c(1,1))
MyData<- data.frame(H1 = seq(from= min(HapDist$HAP1), to = max(HapDist$HAP1), by= 0.1))
P1<-predict(M1, type="link", se=TRUE)
plot(DIST, exp (P1$fit) / (1+exp(P1$fit)),
     type= "l", ylim= c(0,1), xlab= "Distance", ylab= "Haplotype proportion", col= "red")
lines(DIST, exp (P1$fit + 1.96 * P1$se.fit) / (1+exp(P1$fit + 1.96 * P1$se.fit)), lty= 2, col= "red")
lines(DIST, exp (P1$fit - 1.96 * P1$se.fit) / (1+exp(P1$fit - 1.96 * P1$se.fit)), lty= 2, col="red")
points(DIST, H1, col= "red", pch=16, cex=0.8)
par(new=T)
MyData2<- data.frame(H2 = seq(from= min(HapDist$HAP2), to = max(HapDist$HAP2), by= 0.1))
P2<-predict(M2, type="link", se=TRUE)
plot(DIST, exp (P2$fit) / (1+exp(P2$fit)),
     type= "l", ylim= c(0,1), xlab= "Distance", ylab= "Haplotype proportion", col= "blue")
lines(DIST, exp (P2$fit + 1.96 * P2$se.fit) / (1+exp(P2$fit + 1.96 * P2$se.fit)), lty= 2, col= "blue")
lines(DIST, exp (P2$fit - 1.96 * P2$se.fit) / (1+exp(P2$fit - 1.96 * P2$se.fit)), lty= 2, col= "blue")
points(DIST, H2, col="blue", pch=16, cex=0.8)


#########################################################
# Generalized Additive Model (Relationship between genetic and river distance)
#########################################################

#Figure S2: Estimated smoothing curve for the GAM of genetic distance as a function of geographic river distance

M3<- gamm(GD~s(GGD))
summary(M3$gam)
plot(M3$gam, pch=19, cex=0.75, col= "black", xlim= c(0,70))

#Figure 5a: GAM, simulations to examine variation in fitted trend

Rbeta<-mvrnorm(n = 1000, coef(M3$gam), vcov(M3$gam))
Xp<- predict (M3$gam, type="lpmatrix")
sim1<- Xp %*% t(Rbeta)

plot(GD~GGD, type= "p", pch=1, cex=0.7, col= "gray", xlim= c(0,70), ylim=c(0,1))

set.seed(199)
want<- sample(1000,10)
ylim<- range(sim1[,want], IBD$GD)
matlines(IBD$GGD, sim1[,want], col="gray", lty=1, pch=NA)


M4<-predict(M3$gam, se=TRUE)
I1<- order (GGD)
lines(GGD[I1], M4$fit[I1], lty=1, lwd=3, col= "black")


#########################################################
# Mantels Test and Correlogram
#########################################################

#Mantel test
library(ecodist)
mantel(GD~GGD, nperm=10000, nboot= 1000)


#Figure 5b: Mantel correlogram
MGRAM<-mgram(GD, GGD,breaks= c(5,10,15,20,25,30,35,40,45,50,55,60,65,70), nperm=10000, nboot= 1000)
plot(MGRAM)
MGRAM